@@ -35,22 +35,54 @@ pub enum AlterTableOperation {
         if_exists: bool,
         cascade: bool,
     },
+    /// `RENAME TO PARTITION (partition=val)`
+    RenamePartitions {
+        old_partitions: Vec<Expr>,
+        new_partitions: Vec<Expr>,
+    },
+    /// Add Partitions
+    AddPartitions {
+        if_not_exists: bool,
+        new_partitions: Vec<Expr>,
+    },
+    DropPartitions {
+        partitions: Vec<Expr>,
+        if_exists: bool,
+    },
     /// `RENAME [ COLUMN ] <old_column_name> TO <new_column_name>`
     RenameColumn {
         old_column_name: Ident,
         new_column_name: Ident,
     },
     /// `RENAME TO <table_name>`
-    RenameTable { table_name: Ident },
+    RenameTable { table_name: ObjectName },
 }
 
 impl fmt::Display for AlterTableOperation {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         match self {
+            AlterTableOperation::AddPartitions {
+                if_not_exists,
+                new_partitions,
+            } => write!(
+                f,
+                "ADD{ine} PARTITION ({})",
+                display_comma_separated(new_partitions),
+                ine = if *if_not_exists { " IF NOT EXISTS" } else { "" }
+            ),
             AlterTableOperation::AddConstraint(c) => write!(f, "ADD {}", c),
             AlterTableOperation::AddColumn { column_def } => {
                 write!(f, "ADD COLUMN {}", column_def.to_string())
             }
+            AlterTableOperation::DropPartitions {
+                partitions,
+                if_exists,
+            } => write!(
+                f,
+                "DROP{ie} PARTITION ({})",
+                display_comma_separated(partitions),
+                ie = if *if_exists { " IF EXISTS" } else { "" }
+            ),
             AlterTableOperation::DropConstraint { name } => write!(f, "DROP CONSTRAINT {}", name),
             AlterTableOperation::DropColumn {
                 column_name,
@@ -63,6 +95,15 @@ impl fmt::Display for AlterTableOperation {
                 column_name,
                 if *cascade { " CASCADE" } else { "" }
             ),
+            AlterTableOperation::RenamePartitions {
+                old_partitions,
+                new_partitions,
+            } => write!(
+                f,
+                "PARTITION ({}) RENAME TO PARTITION ({})",
+                display_comma_separated(old_partitions),
+                display_comma_separated(new_partitions)
+            ),
             AlterTableOperation::RenameColumn {
                 old_column_name,
                 new_column_name,
@@ -254,7 +295,7 @@ impl fmt::Display for ColumnOption {
     }
 }
 
-fn display_constraint_name<'a>(name: &'a Option<Ident>) -> impl fmt::Display + 'a {
+fn display_constraint_name(name: &'_ Option<Ident>) -> impl fmt::Display + '_ {
     struct ConstraintName<'a>(&'a Option<Ident>);
     impl<'a> fmt::Display for ConstraintName<'a> {
         fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
